@@ -29,7 +29,8 @@ class V1(Serializer):
             name=interface.name,
             bond_master=interface.bond_master,
             auto_negotiation=interface.auto_negotiation,
-            force_up=interface.force_up
+            force_up=interface.force_up,
+            recovery_timeout=interface.recovery_timeout
         )
 
     def to_core(self, serialized):
